@@ -4,7 +4,7 @@ import json
 import requests
 
 from .config import HUB_API_ROOT
-from .utils.general import colorstr
+from .utils.general import colorstr, emojis
 
 PREFIX = colorstr('Ultralytics: ')
 
@@ -65,14 +65,15 @@ class Auth:
         self.validate_api_key(api_key)
         if not self.api_key:
             attempts += 1
-            print(f"{PREFIX}Invalid API key.\n")
+            print(emojis(f"{PREFIX}Invalid API key ⚠️\n"))
 
             if attempts <= 3:
                 return self.attempt_api_key(attempts)
             else:
-                print(f"{PREFIX}Failed to authenticate.")
+                print(emojis(f"{PREFIX}Failed to authenticate ❌"))
                 return False
         else:
+            print(emojis(f"{PREFIX}Authenticated ✅"))
             return True
 
     def validate_api_key(self, api_key):
